# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from volcengine.tls.TLSService import TLSService
from volcengine.tls.tls_requests import *


if __name__ == "__main__":
    # 请查询控制台，填写以下参数值
    endpoint = ""
    access_key_id = ""
    access_key_secret = ""
    region = ""

    # 实例化TLS客户端
    tls_service = TLSService(endpoint, access_key_id, access_key_secret, region)

    # 创建日志项目
    create_project_request = CreateProjectRequest(project_name="project-name", region=region,
                                                  description="project-description")
    create_project_response = tls_service.create_project(create_project_request)
    project_id = create_project_response.project_id

    # 创建日志主题
    create_topic_request = CreateTopicRequest(topic_name="topic-name", project_id=project_id,
                                              ttl=3650, description="topic-description", shard_count=2)
    create_topic_response = tls_service.create_topic(create_topic_request)
    topic_id = create_topic_response.topic_id

    # 创建采集配置
    rule_name = "rule-name"
    paths = ["/data/nginx/log/*/*/*.log"]
    log_type = "delimiter_log"
    extract_rule = ExtractRule(delimiter="#", keys=["time", "", "level", "msg"],
                               time_key="time", time_format="%Y-%m-%dT%H:%M:%S,%f",
                               filter_key_regex=[FilterKeyRegex("msg", ".*ERROR.*")],
                               un_match_up_load_switch=True, un_match_log_key="LogParseFailed")
    exclude_paths = [ExcludePath("File", "/data/nginx/log/*/*/exclude.log"),
                     ExcludePath("Path", "/data/nginx/log/*/exclude/")]
    user_define_rule = UserDefineRule(ParsePathRule(path_sample="/var/logs/instanceid_any_podname/test.log",
                                                    regex="\\/var\\/logs\\/([a-z]*)_any_([a-z]*)\\/test\\.log",
                                                    keys=["instance-id", "pod-name"]))
    log_sample = "2018-05-22 15:35:53.850 INFO XXXX"
    input_type = 2
    container_rule = ContainerRule(container_name_regex=".*Name.*",
                                   include_container_label_regex={"Key1": "Value1", "Key2": "Value2"},
                                   exclude_container_label_regex={"Key1": "Value1", "Key2": "Value2"},
                                   include_container_env_regex={"Key1": "Value1", "Key2": "Value2"},
                                   exclude_container_env_regex={"Key1": "Value1", "Key2": "Value2"},
                                   env_tag={"Key1": "Value1", "Key2": "Value2"},
                                   kubernetes_rule=KubernetesRule(namespace_name_regex=".*Name.*",
                                                                  workload_type="Deployment",
                                                                  workload_name_regex=".*workload.*",
                                                                  include_pod_label_regex={"Key1": "Value1",
                                                                                           "Key2": "Value2"},
                                                                  exclude_pod_label_regex={"Key1": "Value1",
                                                                                           "Key2": "Value2"},
                                                                  pod_name_regex=".*Name.*",
                                                                  label_tag={"Key1": "Value1", "Key2": "Value2"}))
    create_rule_request = CreateRuleRequest(topic_id, rule_name, paths, log_type, extract_rule, exclude_paths,
                                            user_define_rule, log_sample, input_type, container_rule)
    create_rule_response = tls_service.create_rule(create_rule_request)
    rule_id = create_rule_response.rule_id

    # 查询指定采集配置
    describe_rule_request = DescribeRuleRequest(rule_id)
    describe_rule_response = tls_service.describe_rule(describe_rule_request)

    # 查询日志项目所有采集配置
    describe_rules_request = DescribeRulesRequest(project_id)
    describe_rules_response = tls_service.describe_rules(describe_rules_request)

    # 修改采集配置
    modify_rule_request = ModifyRuleRequest(rule_id, rule_name="change-rule-name")
    modify_rule_response = tls_service.modify_rule(modify_rule_request)

    # 创建机器组
    create_host_group_request = CreateHostGroupRequest(host_group_name="host-group-name", host_group_type="IP",
                                                       host_ip_list=["192.168.1.1", "192.168.1.2", "192.168.1.3"])
    create_host_group_response = tls_service.create_host_group(create_host_group_request)
    host_group_id = create_host_group_response.host_group_id

    # 应用采集配置到机器组
    apply_rule_to_host_groups_request = ApplyRuleToHostGroupsRequest(rule_id, host_group_ids=[host_group_id])
    apply_rule_to_host_groups_response = tls_service.apply_rule_to_host_groups(apply_rule_to_host_groups_request)

    # 删除机器组的采集配置
    delete_rule_from_host_groups_request = DeleteRuleFromHostGroupsRequest(rule_id, host_group_ids=[host_group_id])
    delete_rule_from_host_groups_response = tls_service.delete_rule_from_host_groups(delete_rule_from_host_groups_request)

    # 删除采集配置
    delete_rule_request = DeleteRuleRequest(rule_id)
    delete_rule_response = tls_service.delete_rule(delete_rule_request)



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    update_axne_form = {
        "NumberPoolNo": "NP167091934402820309",
        "SubId": "S1672985491953460b645f",
        "UpdateType": "updatePhoneNoB",
        "PhoneNoB": "189000000001",
    }
    print(secretNumberService.update_axne(update_axne_form))



# coding:utf-8
from __future__ import print_function

from volcengine.bioos.BioOsService import BioOsService

if __name__ == '__main__':
    # set endpoint/region here if the default value is unsatisfied
    bioos_service = BioOsService(endpoint='endpoint', region='region')

    # call below method if you don't set ak and sk in $HOME/.volc/config
    bioos_service.set_ak('ak')
    bioos_service.set_sk('sk')

    params = {
        'WorkspaceID': 'workspace_id',
        'Name': 'file_name',
        'Headers': ['my_entity_id', 'column-1-file-CRAM', 'date'],
        'Rows': [
            ['your-sample-1-id', 'https:test.tos-cn-beijing.volces.com/file1.cram', '01/01/2022'],
            ['your-sample-2-id', 'https:test.tos-cn-beijing.volces.com/file2.cram', '01/01/2022'],
            ['your-sample-3-id', 'https:test.tos-cn-beijing.volces.com/file3.cram', '01/01/2022']
        ],
    }

    resp = bioos_service.create_data_model(params)
    print(resp)



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

from volcengine.tls.TLSService import TLSService
from volcengine.tls.tls_requests import *


if __name__ == "__main__":
    # 请查询控制台，填写以下参数值
    endpoint = ""
    access_key_id = ""
    access_key_secret = ""
    region = ""

    # 实例化TLS客户端
    tls_service = TLSService(endpoint, access_key_id, access_key_secret, region)

    # 创建日志项目
    create_project_request = CreateProjectRequest(project_name="project-name", region=region,
                                                  description="project-description")
    create_project_response = tls_service.create_project(create_project_request)
    project_id = create_project_response.project_id

    # 查询指定日志项目信息
    describe_project_request = DescribeProjectRequest(project_id)
    describe_project_response = tls_service.describe_project(describe_project_request)

    # 查询所有日志项目信息
    describe_projects_request = DescribeProjectsRequest()
    describe_projects_response = tls_service.describe_projects(describe_projects_request)

    # 修改日志项目
    modify_project_request = ModifyProjectRequest(project_id, project_name="change-project-name",
                                                  description="change-project-description")
    modify_project_response = tls_service.modify_project(modify_project_request)

    # 删除日志项目
    delete_project_request = DeleteProjectRequest(project_id)
    delete_project_response = tls_service.delete_project(delete_project_request)



# coding=utf-8
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import hashlib
import logging
import threading

from requests.adapters import HTTPAdapter, Retry

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.auth.SignerV4 import SignerV4
from volcengine.base.Service import Service
from volcengine.tls.tls_requests import *
from volcengine.tls.tls_responses import *
from volcengine.tls.tls_exception import TLSException

logging.basicConfig(level=logging.DEBUG, format="%(asctime)s \t %(levelname)s \t %(message)s",
                    datefmt="%Y-%m-%d %H:%M:%S")

API_INFO = {
    # APIs of log projects.
    CREATE_PROJECT: ApiInfo(HTTP_POST, CREATE_PROJECT, {}, {}, {}),
    DELETE_PROJECT: ApiInfo(HTTP_DELETE, DELETE_PROJECT, {}, {}, {}),
    MODIFY_PROJECT: ApiInfo(HTTP_PUT, MODIFY_PROJECT, {}, {}, {}),
    DESCRIBE_PROJECT: ApiInfo(HTTP_GET, DESCRIBE_PROJECT, {}, {}, {}),
    DESCRIBE_PROJECTS: ApiInfo(HTTP_GET, DESCRIBE_PROJECTS, {}, {}, {}),
    # APIs of log topics.
    CREATE_TOPIC: ApiInfo(HTTP_POST, CREATE_TOPIC, {}, {}, {}),
    DELETE_TOPIC: ApiInfo(HTTP_DELETE, DELETE_TOPIC, {}, {}, {}),
    MODIFY_TOPIC: ApiInfo(HTTP_PUT, MODIFY_TOPIC, {}, {}, {}),
    DESCRIBE_TOPIC: ApiInfo(HTTP_GET, DESCRIBE_TOPIC, {}, {}, {}),
    DESCRIBE_TOPICS: ApiInfo(HTTP_GET, DESCRIBE_TOPICS, {}, {}, {}),
    # APIs of log index.
    CREATE_INDEX: ApiInfo(HTTP_POST, CREATE_INDEX, {}, {}, {}),
    DELETE_INDEX: ApiInfo(HTTP_DELETE, DELETE_INDEX, {}, {}, {}),
    MODIFY_INDEX: ApiInfo(HTTP_PUT, MODIFY_INDEX, {}, {}, {}),
    DESCRIBE_INDEX: ApiInfo(HTTP_GET, DESCRIBE_INDEX, {}, {}, {}),
    # APIs of logs.
    PUT_LOGS: ApiInfo(HTTP_POST, PUT_LOGS, {}, {}, {}),
    DESCRIBE_CURSOR: ApiInfo(HTTP_GET, DESCRIBE_CURSOR, {}, {}, {}),
    CONSUME_LOGS: ApiInfo(HTTP_GET, CONSUME_LOGS, {}, {}, {}),
    SEARCH_LOGS: ApiInfo(HTTP_POST, SEARCH_LOGS, {}, {}, {}),
    DESCRIBE_LOG_CONTEXT: ApiInfo(HTTP_POST, DESCRIBE_LOG_CONTEXT, {}, {}, {}),
    WEB_TRACKS: ApiInfo(HTTP_POST, WEB_TRACKS, {}, {}, {}),
    DESCRIBE_HISTOGRAM: ApiInfo(HTTP_POST, DESCRIBE_HISTOGRAM, {}, {}, {}),
    CREATE_DOWNLOAD_TASK: ApiInfo(HTTP_POST, CREATE_DOWNLOAD_TASK, {}, {}, {}),
    DESCRIBE_DOWNLOAD_TASKS: ApiInfo(HTTP_GET, DESCRIBE_DOWNLOAD_TASKS, {}, {}, {}),
    DESCRIBE_DOWNLOAD_URL: ApiInfo(HTTP_GET, DESCRIBE_DOWNLOAD_URL, {}, {}, {}),
    # APIs of shards.
    DESCRIBE_SHARDS: ApiInfo(HTTP_GET, DESCRIBE_SHARDS, {}, {}, {}),
    # APIs of host groups.
    CREATE_HOST_GROUP: ApiInfo(HTTP_POST, CREATE_HOST_GROUP, {}, {}, {}),
    DELETE_HOST_GROUP: ApiInfo(HTTP_DELETE, DELETE_HOST_GROUP, {}, {}, {}),
    MODIFY_HOST_GROUP: ApiInfo(HTTP_PUT, MODIFY_HOST_GROUP, {}, {}, {}),
    DESCRIBE_HOST_GROUP: ApiInfo(HTTP_GET, DESCRIBE_HOST_GROUP, {}, {}, {}),
    DESCRIBE_HOST_GROUPS: ApiInfo(HTTP_GET, DESCRIBE_HOST_GROUPS, {}, {}, {}),
    DESCRIBE_HOSTS: ApiInfo(HTTP_GET, DESCRIBE_HOSTS, {}, {}, {}),
    DELETE_HOST: ApiInfo(HTTP_DELETE, DELETE_HOST, {}, {}, {}),
    DESCRIBE_HOST_GROUP_RULES: ApiInfo(HTTP_GET, DESCRIBE_HOST_GROUP_RULES, {}, {}, {}),
    MODIFY_HOST_GROUPS_AUTO_UPDATE: ApiInfo(HTTP_PUT, MODIFY_HOST_GROUPS_AUTO_UPDATE, {}, {}, {}),
    # APIs of rules.
    CREATE_RULE: ApiInfo(HTTP_POST, CREATE_RULE, {}, {}, {}),
    DELETE_RULE: ApiInfo(HTTP_DELETE, DELETE_RULE, {}, {}, {}),
    MODIFY_RULE: ApiInfo(HTTP_PUT, MODIFY_RULE, {}, {}, {}),
    DESCRIBE_RULE: ApiInfo(HTTP_GET, DESCRIBE_RULE, {}, {}, {}),
    DESCRIBE_RULES: ApiInfo(HTTP_GET, DESCRIBE_RULES, {}, {}, {}),
    APPLY_RULE_TO_HOST_GROUPS: ApiInfo(HTTP_PUT, APPLY_RULE_TO_HOST_GROUPS, {}, {}, {}),
    DELETE_RULE_FROM_HOST_GROUPS: ApiInfo(HTTP_PUT, DELETE_RULE_FROM_HOST_GROUPS, {}, {}, {}),
    # APIs of alarms.
    CREATE_ALARM_NOTIFY_GROUP: ApiInfo(HTTP_POST, CREATE_ALARM_NOTIFY_GROUP, {}, {}, {}),
    DELETE_ALARM_NOTIFY_GROUP: ApiInfo(HTTP_DELETE, DELETE_ALARM_NOTIFY_GROUP, {}, {}, {}),
    MODIFY_ALARM_NOTIFY_GROUP: ApiInfo(HTTP_PUT, MODIFY_ALARM_NOTIFY_GROUP, {}, {}, {}),
    DESCRIBE_ALARM_NOTIFY_GROUPS: ApiInfo(HTTP_GET, DESCRIBE_ALARM_NOTIFY_GROUPS, {}, {}, {}),
    CREATE_ALARM: ApiInfo(HTTP_POST, CREATE_ALARM, {}, {}, {}),
    DELETE_ALARM: ApiInfo(HTTP_DELETE, DELETE_ALARM, {}, {}, {}),
    MODIFY_ALARM: ApiInfo(HTTP_PUT, MODIFY_ALARM, {}, {}, {}),
    DESCRIBE_ALARMS: ApiInfo(HTTP_GET, DESCRIBE_ALARMS, {}, {}, {}),
    # APIs of Kafka consumer.
    OPEN_KAFKA_CONSUMER: ApiInfo(HTTP_PUT, OPEN_KAFKA_CONSUMER, {}, {}, {}),
    CLOSE_KAFKA_CONSUMER: ApiInfo(HTTP_PUT, CLOSE_KAFKA_CONSUMER, {}, {}, {}),
    DESCRIBE_KAFKA_CONSUMER: ApiInfo(HTTP_GET, DESCRIBE_KAFKA_CONSUMER, {}, {}, {})}


class TLSService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(TLSService, "_instance"):
            with TLSService._instance_lock:
                if not hasattr(TLSService, "_instance"):
                    TLSService._instance = object.__new__(cls)

        return TLSService._instance

    def __init__(self, endpoint: str, access_key_id: str, access_key_secret: str, region: str,
                 security_token: str = None, scheme: str = "https", timeout: int = 60, max_retries: int = 10):
        self.__endpoint = endpoint
        self.__access_key_id = access_key_id
        self.__access_key_secret = access_key_secret
        self.__region = region
        self.__security_token = security_token
        self.__scheme = scheme
        self.__timeout = timeout

        super(TLSService, self).__init__(service_info=self.get_service_info(), api_info=API_INFO)

        self.__retry_strategy = Retry(total=max_retries, connect=max_retries, read=max_retries, status=max_retries,
                                      allowed_methods=frozenset([HTTP_GET]),
                                      status_forcelist=frozenset([429, 500, 502, 503, 504, 505]),
                                      backoff_factor=1, raise_on_redirect=False, raise_on_status=False)
        self.__http_adapter = HTTPAdapter(max_retries=self.__retry_strategy)
        self.session.mount(HTTP_PREFIX, self.__http_adapter)
        self.session.mount(HTTPS_PREFIX, self.__http_adapter)

        logging.info("Successfully initialized a TLS client.\n")

    def get_region(self):
        return self.__region

    def get_service_info(self):
        header = {}

        if self.__security_token is not None:
            header[X_SECURITY_TOKEN] = self.__security_token

        credentials = Credentials(ak=self.__access_key_id, sk=self.__access_key_secret,
                                  service="TLS", region=self.__region)
        service_info = ServiceInfo(host=self.__endpoint, header=header, credentials=credentials, scheme=self.__scheme,
                                   connection_timeout=self.__timeout, socket_timeout=self.__timeout)

        return service_info

    def __prepare_request(self, api: str, params: dict = None, body: dict = None, request_headers: dict = None):
        if params is None:
            params = {}
        if body is None:
            body = {}

        request = self.prepare_request(self.api_info[api], params)

        if request_headers is None:
            request_headers = {CONTENT_TYPE: APPLICATION_JSON}
        request.headers.update(request_headers)

        if "json" in request.headers[CONTENT_TYPE] and api != WEB_TRACKS:
            request.body = json.dumps(body)
        else:
            request.body = body[DATA]

        if len(request.body) != 0:
            if isinstance(request.body, str):
                request.headers[CONTENT_MD5] = hashlib.md5(request.body.encode("utf-8")).hexdigest()
            else:
                request.headers[CONTENT_MD5] = hashlib.md5(request.body).hexdigest()

        SignerV4.sign(request, self.service_info.credentials)

        return request

    def __request(self, api: str, params: dict = None, body: dict = None, request_headers: dict = None):
        # logging.info("Requesting {}...\tParams = {}\tBody = {}".format(api, params, body))

        request = self.__prepare_request(api, params, body, request_headers)

        method = self.api_info[api].method
        url = request.build()

        try:
            response = self.session.request(method, url, headers=request.headers, data=request.body,
                                            timeout=self.__timeout)
        except Exception as e:
            raise TLSException(error_code=e.__class__.__name__, error_message=e.__str__())
        else:
            if response.status_code != OK_STATUS:
                raise TLSException(response)

            # logging.info("Successfully got a response from TLS!\n")

            return response

    def reset_access_key_token(self, access_key_id: str, access_key_secret: str, security_token: str = None):
        self.__access_key_id = access_key_id
        self.__access_key_secret = access_key_secret
        self.__security_token = security_token
        self.service_info = self.get_service_info()

    def set_timeout(self, timeout: int):
        self.__timeout = timeout
        self.service_info = self.get_service_info()

    def create_project(self, create_project_request: CreateProjectRequest) -> CreateProjectResponse:
        response = self.__request(api=CREATE_PROJECT, body=create_project_request.get_api_input())

        return CreateProjectResponse(response)

    def delete_project(self, delete_project_request: DeleteProjectRequest) -> DeleteProjectResponse:
        response = self.__request(api=DELETE_PROJECT, body=delete_project_request.get_api_input())

        return DeleteProjectResponse(response)

    def modify_project(self, modify_project_request: ModifyProjectRequest) -> ModifyProjectResponse:
        response = self.__request(api=MODIFY_PROJECT, body=modify_project_request.get_api_input())

        return ModifyProjectResponse(response)

    def describe_project(self, describe_project_request: DescribeProjectRequest) -> DescribeProjectResponse:
        response = self.__request(api=DESCRIBE_PROJECT, params=describe_project_request.get_api_input())

        return DescribeProjectResponse(response)

    def describe_projects(self, describe_projects_request: DescribeProjectsRequest) -> DescribeProjectsResponse:
        response = self.__request(api=DESCRIBE_PROJECTS, params=describe_projects_request.get_api_input())

        return DescribeProjectsResponse(response)

    def create_topic(self, create_topic_request: CreateTopicRequest) -> CreateTopicResponse:
        response = self.__request(api=CREATE_TOPIC, body=create_topic_request.get_api_input())

        return CreateTopicResponse(response)

    def delete_topic(self, delete_topic_request: DeleteTopicRequest) -> DeleteTopicResponse:
        response = self.__request(api=DELETE_TOPIC, body=delete_topic_request.get_api_input())

        return DeleteTopicResponse(response)

    def modify_topic(self, modify_topic_request: ModifyTopicRequest) -> ModifyTopicResponse:
        response = self.__request(api=MODIFY_TOPIC, body=modify_topic_request.get_api_input())

        return ModifyTopicResponse(response)

    def describe_topic(self, describe_topic_request: DescribeTopicRequest) -> DescribeTopicResponse:
        response = self.__request(api=DESCRIBE_TOPIC, params=describe_topic_request.get_api_input())

        return DescribeTopicResponse(response)

    def describe_topics(self, describe_topics_request: DescribeTopicsRequest) -> DescribeTopicsResponse:
        response = self.__request(api=DESCRIBE_TOPICS, params=describe_topics_request.get_api_input())

        return DescribeTopicsResponse(response)

    def create_index(self, create_index_request: CreateIndexRequest) -> CreateIndexResponse:
        response = self.__request(api=CREATE_INDEX, body=create_index_request.get_api_input())

        return CreateIndexResponse(response)

    def delete_index(self, delete_index_request: DeleteIndexRequest) -> DeleteIndexResponse:
        response = self.__request(api=DELETE_INDEX, body=delete_index_request.get_api_input())

        return DeleteIndexResponse(response)

    def modify_index(self, modify_index_request: ModifyIndexRequest) -> ModifyIndexResponse:
        response = self.__request(api=MODIFY_INDEX, body=modify_index_request.get_api_input())

        return ModifyIndexResponse(response)

    def describe_index(self, describe_index_request: DescribeIndexRequest) -> DescribeIndexResponse:
        response = self.__request(api=DESCRIBE_INDEX, params=describe_index_request.get_api_input())

        return DescribeIndexResponse(response)

    def put_logs(self, put_logs_request: PutLogsRequest) -> PutLogsResponse:
        api_input = put_logs_request.get_api_input()
        response = self.__request(api=PUT_LOGS, params=api_input[PARAMS], body=api_input[BODY],
                                  request_headers=api_input[REQUEST_HEADERS])

        return PutLogsResponse(response)

    def describe_cursor(self, describe_cursor_request: DescribeCursorRequest) -> DescribeCursorResponse:
        api_input = describe_cursor_request.get_api_input()
        response = self.__request(api=DESCRIBE_CURSOR, params=api_input[PARAMS], body=api_input[BODY])

        return DescribeCursorResponse(response)

    def consume_logs(self, consume_logs_request: ConsumeLogsRequest) -> ConsumeLogsResponse:
        api_input = consume_logs_request.get_api_input()
        response = self.__request(api=CONSUME_LOGS, params=api_input[PARAMS], body=api_input[BODY])

        return ConsumeLogsResponse(response, compression=consume_logs_request.compression)

    def search_logs(self, search_logs_request: SearchLogsRequest) -> SearchLogsResponse:
        response = self.__request(api=SEARCH_LOGS, body=search_logs_request.get_api_input())

        return SearchLogsResponse(response)

    def describe_log_context(self, describe_log_context_request: DescribeLogContextRequest) \
            -> DescribeLogContextResponse:
        response = self.__request(api=DESCRIBE_LOG_CONTEXT, body=describe_log_context_request.get_api_input())

        return DescribeLogContextResponse(response)

    def web_tracks(self, web_tracks_request: WebTracksRequest) -> WebTracksResponse:
        api_input = web_tracks_request.get_api_input()
        response = self.__request(api=WEB_TRACKS, params=api_input[PARAMS], body=api_input[BODY],
                                  request_headers=api_input[REQUEST_HEADERS])

        return WebTracksResponse(response)

    def describe_histogram(self, describe_histogram_request: DescribeHistogramRequest) -> DescribeHistogramResponse:
        response = self.__request(api=DESCRIBE_HISTOGRAM, body=describe_histogram_request.get_api_input())

        return DescribeHistogramResponse(response)

    def create_download_task(self, create_download_task_request: CreateDownloadTaskRequest) \
            -> CreateDownloadTaskResponse:
        response = self.__request(api=CREATE_DOWNLOAD_TASK, body=create_download_task_request.get_api_input())

        return CreateDownloadTaskResponse(response)

    def describe_download_tasks(self, describe_download_tasks_request: DescribeDownloadTasksRequest) \
            -> DescribeDownloadTasksResponse:
        response = self.__request(api=DESCRIBE_DOWNLOAD_TASKS, params=describe_download_tasks_request.get_api_input())

        return DescribeDownloadTasksResponse(response)

    def describe_download_url(self, describe_download_url_request: DescribeDownloadUrlRequest)\
            -> DescribeDownloadUrlResponse:
        response = self.__request(api=DESCRIBE_DOWNLOAD_URL, params=describe_download_url_request.get_api_input())

        return DescribeDownloadUrlResponse(response)

    def describe_shards(self, describe_shards_request: DescribeShardsRequest) -> DescribeShardsResponse:
        response = self.__request(api=DESCRIBE_SHARDS, params=describe_shards_request.get_api_input())

        return DescribeShardsResponse(response)

    def create_host_group(self, create_host_group_request: CreateHostGroupRequest) -> CreateHostGroupResponse:
        response = self.__request(api=CREATE_HOST_GROUP, body=create_host_group_request.get_api_input())

        return CreateHostGroupResponse(response)

    def delete_host_group(self, delete_host_group_request: DeleteHostGroupRequest) -> DeleteHostGroupResponse:
        response = self.__request(api=DELETE_HOST_GROUP, body=delete_host_group_request.get_api_input())

        return DeleteHostGroupResponse(response)

    def modify_host_group(self, modify_host_group_request: ModifyHostGroupRequest) -> ModifyHostGroupResponse:
        response = self.__request(api=MODIFY_HOST_GROUP, body=modify_host_group_request.get_api_input())

        return ModifyHostGroupResponse(response)

    def describe_host_group(self, describe_host_group_request: DescribeHostGroupRequest) -> DescribeHostGroupResponse:
        response = self.__request(api=DESCRIBE_HOST_GROUP, params=describe_host_group_request.get_api_input())

        return DescribeHostGroupResponse(response)

    def describe_host_groups(self, describe_host_groups_request: DescribeHostGroupsRequest) \
            -> DescribeHostGroupsResponse:
        response = self.__request(api=DESCRIBE_HOST_GROUPS, params=describe_host_groups_request.get_api_input())

        return DescribeHostGroupsResponse(response)

    def describe_hosts(self, describe_hosts_request: DescribeHostsRequest) -> DescribeHostsResponse:
        response = self.__request(api=DESCRIBE_HOSTS, params=describe_hosts_request.get_api_input())

        return DescribeHostsResponse(response)

    def delete_host(self, delete_host_request: DeleteHostRequest) -> DeleteHostResponse:
        response = self.__request(api=DELETE_HOST, body=delete_host_request.get_api_input())

        return DeleteHostResponse(response)

    def describe_host_group_rules(self, describe_host_group_rules: DescribeHostGroupRulesRequest) \
            -> DescribeHostGroupRulesResponse:
        response = self.__request(api=DESCRIBE_HOST_GROUP_RULES, params=describe_host_group_rules.get_api_input())

        return DescribeHostGroupRulesResponse(response)

    def modify_host_groups_auto_update(self, modify_host_groups_auto_update_request: ModifyHostGroupsAutoUpdateRequest)\
            -> ModifyHostGroupsAutoUpdateResponse:
        response = self.__request(api=MODIFY_HOST_GROUPS_AUTO_UPDATE,
                                  body=modify_host_groups_auto_update_request.get_api_input())

        return ModifyHostGroupsAutoUpdateResponse(response)

    def create_rule(self, create_rule_request: CreateRuleRequest) -> CreateRuleResponse:
        response = self.__request(api=CREATE_RULE, body=create_rule_request.get_api_input())

        return CreateRuleResponse(response)

    def delete_rule(self, delete_rule_request: DeleteRuleRequest) -> DeleteRuleResponse:
        response = self.__request(api=DELETE_RULE, body=delete_rule_request.get_api_input())

        return DeleteRuleResponse(response)

    def modify_rule(self, modify_rule_request: ModifyRuleRequest) -> ModifyRuleResponse:
        response = self.__request(api=MODIFY_RULE, body=modify_rule_request.get_api_input())

        return ModifyRuleResponse(response)

    def describe_rule(self, describe_rule_request: DescribeRuleRequest) -> DescribeRuleResponse:
        response = self.__request(api=DESCRIBE_RULE, params=describe_rule_request.get_api_input())

        return DescribeRuleResponse(response)

    def describe_rules(self, describe_rules_request: DescribeRulesRequest) -> DescribeRulesResponse:
        response = self.__request(api=DESCRIBE_RULES, params=describe_rules_request.get_api_input())

        return DescribeRulesResponse(response)

    def apply_rule_to_host_groups(self, apply_rule_to_host_groups_request: ApplyRuleToHostGroupsRequest) \
            -> ApplyRuleToHostGroupsResponse:
        response = self.__request(api=APPLY_RULE_TO_HOST_GROUPS, body=apply_rule_to_host_groups_request.get_api_input())

        return ApplyRuleToHostGroupsResponse(response)

    def delete_rule_from_host_groups(self, delete_rule_from_host_groups_request: DeleteRuleFromHostGroupsRequest) \
            -> DeleteRuleFromHostGroupsResponse:
        response = self.__request(api=DELETE_RULE_FROM_HOST_GROUPS,
                                  body=delete_rule_from_host_groups_request.get_api_input())

        return DeleteRuleFromHostGroupsResponse(response)

    def create_alarm_notify_group(self, create_alarm_notify_group_request: CreateAlarmNotifyGroupRequest) \
            -> CreateAlarmNotifyGroupResponse:
        response = self.__request(api=CREATE_ALARM_NOTIFY_GROUP, body=create_alarm_notify_group_request.get_api_input())

        return CreateAlarmNotifyGroupResponse(response)

    def delete_alarm_notify_group(self, delete_alarm_notify_group_request: DeleteAlarmNotifyGroupRequest) \
            -> DeleteAlarmNotifyGroupResponse:
        response = self.__request(api=DELETE_ALARM_NOTIFY_GROUP, body=delete_alarm_notify_group_request.get_api_input())

        return DeleteAlarmNotifyGroupResponse(response)

    def modify_alarm_notify_group(self, modify_alarm_notify_group: ModifyAlarmNotifyGroupRequest) \
            -> ModifyAlarmNotifyGroupResponse:
        response = self.__request(api=MODIFY_ALARM_NOTIFY_GROUP, body=modify_alarm_notify_group.get_api_input())

        return ModifyAlarmNotifyGroupResponse(response)

    def describe_alarm_notify_groups(self, describe_alarm_notify_groups: DescribeAlarmNotifyGroupsRequest) \
            -> DescribeAlarmNotifyGroupsResponse:
        response = self.__request(api=DESCRIBE_ALARM_NOTIFY_GROUPS, params=describe_alarm_notify_groups.get_api_input())

        return DescribeAlarmNotifyGroupsResponse(response)

    def create_alarm(self, create_alarm_request: CreateAlarmRequest) -> CreateAlarmResponse:
        response = self.__request(api=CREATE_ALARM, body=create_alarm_request.get_api_input())

        return CreateAlarmResponse(response)

    def delete_alarm(self, delete_alarm_request: DeleteAlarmRequest) -> DeleteAlarmResponse:
        response = self.__request(api=DELETE_ALARM, body=delete_alarm_request.get_api_input())

        return DeleteAlarmResponse(response)

    def modify_alarm(self, modify_alarm_request: ModifyAlarmRequest) -> ModifyAlarmResponse:
        response = self.__request(api=MODIFY_ALARM, body=modify_alarm_request.get_api_input())

        return ModifyAlarmResponse(response)

    def describe_alarms(self, describe_alarms_request: DescribeAlarmsRequest) -> DescribeAlarmsResponse:
        response = self.__request(api=DESCRIBE_ALARMS, params=describe_alarms_request.get_api_input())

        return DescribeAlarmsResponse(response)

    def open_kafka_consumer(self, open_kafka_consumer_request: OpenKafkaConsumerRequest) -> OpenKafkaConsumerResponse:
        response = self.__request(api=OPEN_KAFKA_CONSUMER, body=open_kafka_consumer_request.get_api_input())

        return OpenKafkaConsumerResponse(response)

    def close_kafka_consumer(self, close_kafka_consumer_request: CloseKafkaConsumerRequest) \
            -> CloseKafkaConsumerResponse:
        response = self.__request(api=CLOSE_KAFKA_CONSUMER, body=close_kafka_consumer_request.get_api_input())

        return CloseKafkaConsumerResponse(response)

    def describe_kafka_consumer(self, describe_kafka_consumer_request: DescribeKafkaConsumerRequest)\
            -> DescribeKafkaConsumerResponse:
        response = self.__request(api=DESCRIBE_KAFKA_CONSUMER, params=describe_kafka_consumer_request.get_api_input())

        return DescribeKafkaConsumerResponse(response)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_measure.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1evod/business/vod_measure.proto\x12\x1eVolcengine.Vod.Models.Business\"<\n\x1d\x44\x65scribeVodSpaceTranscodeItem\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x03\"\x8f\x01\n%DescribeVodSpaceTranscodeDetailTVUnit\x12\x0c\n\x04Time\x18\x01 \x01(\t\x12X\n\x11TranscodeItemList\x18\x02 \x03(\x0b\x32=.Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeItem\"\xb5\x01\n\x1f\x44\x65scribeVodSpaceTranscodeDetail\x12\r\n\x05Space\x18\x01 \x01(\t\x12\x11\n\tTaskStage\x18\x02 \x01(\t\x12\r\n\x05Total\x18\x03 \x01(\x03\x12\x61\n\x12TranscodeUsageList\x18\x04 \x03(\x0b\x32\x45.Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeDetailTVUnit\"\xac\x03\n#DescribeVodSpaceTranscodeDataResult\x12\x11\n\tSpaceList\x18\x01 \x03(\t\x12\x11\n\tStartTime\x18\x02 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x03 \x01(\t\x12\x15\n\rTranscodeType\x18\x04 \x01(\t\x12\x15\n\rSpecification\x18\x05 \x01(\t\x12\x15\n\rTaskStageList\x18\x06 \x03(\t\x12\x13\n\x0b\x41ggregation\x18\x07 \x01(\x03\x12\x17\n\x0f\x44\x65tailFieldList\x18\x08 \x03(\t\x12\x1a\n\x12TotalTranscodeData\x18\t \x01(\x03\x12]\n\x16TotalTranscodeDataList\x18\n \x03(\x0b\x32=.Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeItem\x12`\n\x17TranscodeDataDetailList\x18\x0b \x03(\x0b\x32?.Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeDetail\"B\n DescribeVodSpaceAIStatisDataItem\x12\x0c\n\x04Time\x18\x01 \x01(\t\x12\x10\n\x08\x44uration\x18\x02 \x01(\x03\"\xa1\x01\n\"DescribeVodSpaceAIStatisDataDetail\x12\r\n\x05Space\x18\x01 \x01(\t\x12\x11\n\tTaskStage\x18\x02 \x01(\t\x12Y\n\x0f\x41iUsageDataList\x18\x03 \x03(\x0b\x32@.Volcengine.Vod.Models.Business.DescribeVodSpaceAIStatisDataItem\"\x8d\x03\n\"DescribeVodSpaceAIStatisDataResult\x12\x11\n\tSpaceList\x18\x01 \x03(\t\x12\x11\n\tStartTime\x18\x02 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x03 \x01(\t\x12\x13\n\x0bMediaAiType\x18\x04 \x01(\t\x12\x15\n\rTaskStageList\x18\x05 \x03(\t\x12\x13\n\x0b\x41ggregation\x18\x06 \x01(\x03\x12\x17\n\x0f\x44\x65tailFieldList\x18\x07 \x03(\t\x12\x18\n\x10TotalAiUsageData\x18\x08 \x01(\x03\x12Y\n\x0f\x41iUsageDataList\x18\t \x03(\x0b\x32@.Volcengine.Vod.Models.Business.DescribeVodSpaceAIStatisDataItem\x12\x61\n\x15\x41iUsageDataDetailList\x18\n \x03(\x0b\x32\x42.Volcengine.Vod.Models.Business.DescribeVodSpaceAIStatisDataDetail\"E\n&DescribeVodSpaceSubtitleStatisDataItem\x12\x0c\n\x04Time\x18\x01 \x01(\t\x12\r\n\x05Usage\x18\x02 \x01(\x03\"\xb3\x01\n(DescribeVodSpaceSubtitleStatisDataDetail\x12\r\n\x05Space\x18\x01 \x01(\t\x12\x11\n\tTaskStage\x18\x02 \x01(\t\x12\x65\n\x15SubtitleUsageDataList\x18\x03 \x03(\x0b\x32\x46.Volcengine.Vod.Models.Business.DescribeVodSpaceSubtitleStatisDataItem\"\xb2\x03\n(DescribeVodSpaceSubtitleStatisDataResult\x12\x11\n\tSpaceList\x18\x01 \x03(\t\x12\x11\n\tStartTime\x18\x02 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x03 \x01(\t\x12\x14\n\x0cSubtitleType\x18\x04 \x01(\t\x12\x15\n\rTaskStageList\x18\x05 \x03(\t\x12\x13\n\x0b\x41ggregation\x18\x06 \x01(\x03\x12\x17\n\x0f\x44\x65tailFieldList\x18\x07 \x03(\t\x12\x1e\n\x16TotalSubtitleUsageData\x18\x08 \x01(\x03\x12\x65\n\x15SubtitleUsageDataList\x18\t \x03(\x0b\x32\x46.Volcengine.Vod.Models.Business.DescribeVodSpaceSubtitleStatisDataItem\x12m\n\x1bSubtitleUsageDataDetailList\x18\n \x03(\x0b\x32H.Volcengine.Vod.Models.Business.DescribeVodSpaceSubtitleStatisDataDetail\"C\n$DescribeVodSpaceDetectStatisDataItem\x12\x0c\n\x04Time\x18\x01 \x01(\t\x12\r\n\x05Usage\x18\x02 \x01(\x03\"\xad\x01\n&DescribeVodSpaceDetectStatisDataDetail\x12\r\n\x05Space\x18\x01 \x01(\t\x12\x11\n\tTaskStage\x18\x02 \x01(\t\x12\x61\n\x13\x44\x65tectUsageDataList\x18\x03 \x03(\x0b\x32\x44.Volcengine.Vod.Models.Business.DescribeVodSpaceDetectStatisDataItem\"\xa4\x03\n&DescribeVodSpaceDetectStatisDataResult\x12\x11\n\tSpaceList\x18\x01 \x03(\t\x12\x11\n\tStartTime\x18\x02 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x03 \x01(\t\x12\x12\n\nDetectType\x18\x04 \x01(\t\x12\x15\n\rTaskStageList\x18\x05 \x03(\t\x12\x13\n\x0b\x41ggregation\x18\x06 \x01(\x03\x12\x17\n\x0f\x44\x65tailFieldList\x18\x07 \x03(\t\x12\x1c\n\x14TotalDetectUsageData\x18\x08 \x01(\x03\x12\x61\n\x13\x44\x65tectUsageDataList\x18\t \x03(\x0b\x32\x44.Volcengine.Vod.Models.Business.DescribeVodSpaceDetectStatisDataItem\x12i\n\x19\x44\x65tectUsageDataDetailList\x18\n \x03(\x0b\x32\x46.Volcengine.Vod.Models.Business.DescribeVodSpaceDetectStatisDataDetail\":\n\x1b\x44\x65scribeVodSnapshotDataItem\x12\x0c\n\x04Time\x18\x01 \x01(\t\x12\r\n\x05\x43ount\x18\x02 \x01(\x03\"\xa7\x01\n\x1d\x44\x65scribeVodSnapshotDataDetail\x12\r\n\x05Space\x18\x01 \x01(\t\x12\x11\n\tTaskStage\x18\x02 \x01(\t\x12\r\n\x05Total\x18\x03 \x01(\t\x12U\n\x10SnapshotDataList\x18\x04 \x03(\x0b\x32;.Volcengine.Vod.Models.Business.DescribeVodSnapshotDataItem\"\x82\x03\n\x1d\x44\x65scribeVodSnapshotDataResult\x12\x11\n\tSpaceList\x18\x01 \x03(\t\x12\x11\n\tStartTime\x18\x02 \x01(\t\x12\x0f\n\x07\x45ndTime\x18\x03 \x01(\t\x12\x14\n\x0cSnapshotType\x18\x04 \x01(\t\x12\x15\n\rTaskStageList\x18\x05 \x03(\t\x12\x13\n\x0b\x41ggregation\x18\x06 \x01(\x03\x12\x17\n\x0f\x44\x65tailFieldList\x18\x07 \x03(\t\x12\x19\n\x11TotalSnapshotData\x18\x08 \x01(\x03\x12U\n\x10SnapshotDataList\x18\t \x03(\x0b\x32;.Volcengine.Vod.Models.Business.DescribeVodSnapshotDataItem\x12]\n\x16SnapshotDetailDataList\x18\n \x03(\x0b\x32=.Volcengine.Vod.Models.Business.DescribeVodSnapshotDataDetailB\xcb\x01\n)com.volcengine.service.vod.model.businessB\nVodMeasureP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')



_DESCRIBEVODSPACETRANSCODEITEM = DESCRIPTOR.message_types_by_name['DescribeVodSpaceTranscodeItem']
_DESCRIBEVODSPACETRANSCODEDETAILTVUNIT = DESCRIPTOR.message_types_by_name['DescribeVodSpaceTranscodeDetailTVUnit']
_DESCRIBEVODSPACETRANSCODEDETAIL = DESCRIPTOR.message_types_by_name['DescribeVodSpaceTranscodeDetail']
_DESCRIBEVODSPACETRANSCODEDATARESULT = DESCRIPTOR.message_types_by_name['DescribeVodSpaceTranscodeDataResult']
_DESCRIBEVODSPACEAISTATISDATAITEM = DESCRIPTOR.message_types_by_name['DescribeVodSpaceAIStatisDataItem']
_DESCRIBEVODSPACEAISTATISDATADETAIL = DESCRIPTOR.message_types_by_name['DescribeVodSpaceAIStatisDataDetail']
_DESCRIBEVODSPACEAISTATISDATARESULT = DESCRIPTOR.message_types_by_name['DescribeVodSpaceAIStatisDataResult']
_DESCRIBEVODSPACESUBTITLESTATISDATAITEM = DESCRIPTOR.message_types_by_name['DescribeVodSpaceSubtitleStatisDataItem']
_DESCRIBEVODSPACESUBTITLESTATISDATADETAIL = DESCRIPTOR.message_types_by_name['DescribeVodSpaceSubtitleStatisDataDetail']
_DESCRIBEVODSPACESUBTITLESTATISDATARESULT = DESCRIPTOR.message_types_by_name['DescribeVodSpaceSubtitleStatisDataResult']
_DESCRIBEVODSPACEDETECTSTATISDATAITEM = DESCRIPTOR.message_types_by_name['DescribeVodSpaceDetectStatisDataItem']
_DESCRIBEVODSPACEDETECTSTATISDATADETAIL = DESCRIPTOR.message_types_by_name['DescribeVodSpaceDetectStatisDataDetail']
_DESCRIBEVODSPACEDETECTSTATISDATARESULT = DESCRIPTOR.message_types_by_name['DescribeVodSpaceDetectStatisDataResult']
_DESCRIBEVODSNAPSHOTDATAITEM = DESCRIPTOR.message_types_by_name['DescribeVodSnapshotDataItem']
_DESCRIBEVODSNAPSHOTDATADETAIL = DESCRIPTOR.message_types_by_name['DescribeVodSnapshotDataDetail']
_DESCRIBEVODSNAPSHOTDATARESULT = DESCRIPTOR.message_types_by_name['DescribeVodSnapshotDataResult']
DescribeVodSpaceTranscodeItem = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceTranscodeItem', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACETRANSCODEITEM,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeItem)
  })
_sym_db.RegisterMessage(DescribeVodSpaceTranscodeItem)

DescribeVodSpaceTranscodeDetailTVUnit = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceTranscodeDetailTVUnit', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACETRANSCODEDETAILTVUNIT,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeDetailTVUnit)
  })
_sym_db.RegisterMessage(DescribeVodSpaceTranscodeDetailTVUnit)

DescribeVodSpaceTranscodeDetail = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceTranscodeDetail', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACETRANSCODEDETAIL,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeDetail)
  })
_sym_db.RegisterMessage(DescribeVodSpaceTranscodeDetail)

DescribeVodSpaceTranscodeDataResult = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceTranscodeDataResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACETRANSCODEDATARESULT,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceTranscodeDataResult)
  })
_sym_db.RegisterMessage(DescribeVodSpaceTranscodeDataResult)

DescribeVodSpaceAIStatisDataItem = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceAIStatisDataItem', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEAISTATISDATAITEM,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceAIStatisDataItem)
  })
_sym_db.RegisterMessage(DescribeVodSpaceAIStatisDataItem)

DescribeVodSpaceAIStatisDataDetail = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceAIStatisDataDetail', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEAISTATISDATADETAIL,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceAIStatisDataDetail)
  })
_sym_db.RegisterMessage(DescribeVodSpaceAIStatisDataDetail)

DescribeVodSpaceAIStatisDataResult = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceAIStatisDataResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEAISTATISDATARESULT,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceAIStatisDataResult)
  })
_sym_db.RegisterMessage(DescribeVodSpaceAIStatisDataResult)

DescribeVodSpaceSubtitleStatisDataItem = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceSubtitleStatisDataItem', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACESUBTITLESTATISDATAITEM,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceSubtitleStatisDataItem)
  })
_sym_db.RegisterMessage(DescribeVodSpaceSubtitleStatisDataItem)

DescribeVodSpaceSubtitleStatisDataDetail = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceSubtitleStatisDataDetail', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACESUBTITLESTATISDATADETAIL,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceSubtitleStatisDataDetail)
  })
_sym_db.RegisterMessage(DescribeVodSpaceSubtitleStatisDataDetail)

DescribeVodSpaceSubtitleStatisDataResult = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceSubtitleStatisDataResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACESUBTITLESTATISDATARESULT,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceSubtitleStatisDataResult)
  })
_sym_db.RegisterMessage(DescribeVodSpaceSubtitleStatisDataResult)

DescribeVodSpaceDetectStatisDataItem = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceDetectStatisDataItem', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEDETECTSTATISDATAITEM,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceDetectStatisDataItem)
  })
_sym_db.RegisterMessage(DescribeVodSpaceDetectStatisDataItem)

DescribeVodSpaceDetectStatisDataDetail = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceDetectStatisDataDetail', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEDETECTSTATISDATADETAIL,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceDetectStatisDataDetail)
  })
_sym_db.RegisterMessage(DescribeVodSpaceDetectStatisDataDetail)

DescribeVodSpaceDetectStatisDataResult = _reflection.GeneratedProtocolMessageType('DescribeVodSpaceDetectStatisDataResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSPACEDETECTSTATISDATARESULT,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSpaceDetectStatisDataResult)
  })
_sym_db.RegisterMessage(DescribeVodSpaceDetectStatisDataResult)

DescribeVodSnapshotDataItem = _reflection.GeneratedProtocolMessageType('DescribeVodSnapshotDataItem', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSNAPSHOTDATAITEM,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSnapshotDataItem)
  })
_sym_db.RegisterMessage(DescribeVodSnapshotDataItem)

DescribeVodSnapshotDataDetail = _reflection.GeneratedProtocolMessageType('DescribeVodSnapshotDataDetail', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSNAPSHOTDATADETAIL,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSnapshotDataDetail)
  })
_sym_db.RegisterMessage(DescribeVodSnapshotDataDetail)

DescribeVodSnapshotDataResult = _reflection.GeneratedProtocolMessageType('DescribeVodSnapshotDataResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEVODSNAPSHOTDATARESULT,
  '__module__' : 'vod.business.vod_measure_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.DescribeVodSnapshotDataResult)
  })
_sym_db.RegisterMessage(DescribeVodSnapshotDataResult)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\nVodMeasureP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _DESCRIBEVODSPACETRANSCODEITEM._serialized_start=66
  _DESCRIBEVODSPACETRANSCODEITEM._serialized_end=126
  _DESCRIBEVODSPACETRANSCODEDETAILTVUNIT._serialized_start=129
  _DESCRIBEVODSPACETRANSCODEDETAILTVUNIT._serialized_end=272
  _DESCRIBEVODSPACETRANSCODEDETAIL._serialized_start=275
  _DESCRIBEVODSPACETRANSCODEDETAIL._serialized_end=456
  _DESCRIBEVODSPACETRANSCODEDATARESULT._serialized_start=459
  _DESCRIBEVODSPACETRANSCODEDATARESULT._serialized_end=887
  _DESCRIBEVODSPACEAISTATISDATAITEM._serialized_start=889
  _DESCRIBEVODSPACEAISTATISDATAITEM._serialized_end=955
  _DESCRIBEVODSPACEAISTATISDATADETAIL._serialized_start=958
  _DESCRIBEVODSPACEAISTATISDATADETAIL._serialized_end=1119
  _DESCRIBEVODSPACEAISTATISDATARESULT._serialized_start=1122
  _DESCRIBEVODSPACEAISTATISDATARESULT._serialized_end=1519
  _DESCRIBEVODSPACESUBTITLESTATISDATAITEM._serialized_start=1521
  _DESCRIBEVODSPACESUBTITLESTATISDATAITEM._serialized_end=1590
  _DESCRIBEVODSPACESUBTITLESTATISDATADETAIL._serialized_start=1593
  _DESCRIBEVODSPACESUBTITLESTATISDATADETAIL._serialized_end=1772
  _DESCRIBEVODSPACESUBTITLESTATISDATARESULT._serialized_start=1775
  _DESCRIBEVODSPACESUBTITLESTATISDATARESULT._serialized_end=2209
  _DESCRIBEVODSPACEDETECTSTATISDATAITEM._serialized_start=2211
  _DESCRIBEVODSPACEDETECTSTATISDATAITEM._serialized_end=2278
  _DESCRIBEVODSPACEDETECTSTATISDATADETAIL._serialized_start=2281
  _DESCRIBEVODSPACEDETECTSTATISDATADETAIL._serialized_end=2454
  _DESCRIBEVODSPACEDETECTSTATISDATARESULT._serialized_start=2457
  _DESCRIBEVODSPACEDETECTSTATISDATARESULT._serialized_end=2877
  _DESCRIBEVODSNAPSHOTDATAITEM._serialized_start=2879
  _DESCRIBEVODSNAPSHOTDATAITEM._serialized_end=2937
  _DESCRIBEVODSNAPSHOTDATADETAIL._serialized_start=2940
  _DESCRIBEVODSNAPSHOTDATADETAIL._serialized_end=3107
  _DESCRIBEVODSNAPSHOTDATARESULT._serialized_start=3110
  _DESCRIBEVODSNAPSHOTDATARESULT._serialized_end=3496
# @@protoc_insertion_point(module_scope)



# coding:utf-8
from __future__ import print_function

import json

from volcengine.const.Const import *
from volcengine.sms.SmsService import SmsService

if __name__ == '__main__':
    # oversea
    # sms_service = SmsService(REGION_AP_SINGAPORE1)
    # cn
    sms_service = SmsService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    sms_service.set_ak('ak')
    sms_service.set_sk('sk')
    # sms_service.set_scheme("http")
    sms_service.set_scheme("https")
    # sms_service.set_host('host')

    body = {
        "SubAccount": "subAccount",
        "Content": "content",
        "Desc": "description",
        "Source": "公司名称/公司缩写",
        "Domain": "网站域名"
    }

    resp = sms_service.apply_sms_signature(body)
    print(resp)
